#ifndef	_TASK_TFT_H
#define	_TASK_TFT_H

/**
 * @file task_tft.h
 * @brief BrewBoard TFT and Touch screen driver for a 320x240 ILI9341 based display.
 *        But because the application is controlled using the touch screen, all the
 *        processing of menus is also found here.
 *        It's the first started task, but it does nothing until the Main_Screen 
 *        variable is set.
 */

/**
 * @brief Update the JSON structure with the logdata.
 */
void update_json(void);

/**
 * @brief Initialize the TFT display
 */
int init_tft_display(void);

/**
 * @brief Write a big message at the center top of the screen.
 * @param text The text to display
 */
void TopMessage(char *text);

/**
 * @brief Draw Mash Lauter Tun info
 * @param x X startpoint
 * @param y Y startpoint
 * @param update If update or initial draw.
 */
void MLT_info(int x, int y, bool update);

/**
 * @brief Draw Hot Liquer Tank info
 * @param x X startpoint
 * @param y Y startpoint
 * @param update If update or initial draw.
 * @param small To display a smaller box.
 */
void HLT_info(int x, int y, bool update, bool small);

/**
 * @brief Set the timer.
 * @param seconds The number of seconds in the timer.
 */
void TimerSet(uint32_t seconds);

/**
 * @brief Show the timer.
 * @param Time the time to display.
 * @param X the X position to display the time
 * @param Y the Y position to display the time
 */
void TimerShow(uint32_t Time, int X, int Y);

/**
 * @brief Initialize all values for the webui.
 */
void TFTstartWS(int client);

/**
 * @brief FreeRTOS TFT/Touch task. 
 */
void task_tft(void *);

#endif
